From cef444d09a60c6c0cccd09f96a16f0756178b387 Mon Sep 17 00:00:00 2001
From: Colm Talbot <colm.talbot@ligo.org>
Date: Mon, 18 Jun 2018 13:51:30 +1000
Subject: [PATCH] make principal components kwargs

---
 tupak/gw/source.py | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/tupak/gw/source.py b/tupak/gw/source.py
index 81ab36beb..afe9d0cd0 100644
--- a/tupak/gw/source.py
+++ b/tupak/gw/source.py
@@ -146,10 +146,13 @@ def supernova(
 
 
 def supernova_pca_model(
         frequency_array, realPCs, imagPCs, pc_coeff1, pc_coeff2, pc_coeff3,
         pc_coeff4, pc_coeff5, luminosity_distance, ra, dec, geocent_time, psi):
     """ Supernova signal model """
 
+    realPCs = kwargs['realPCs']
+    imagPCs = kwargs['imagPCs']
+
     pc1 = realPCs[:, 0] + 1.0j*imagPCs[:, 0]
     pc2 = realPCs[:, 1] + 1.0j*imagPCs[:, 1]
     pc3 = realPCs[:, 2] + 1.0j*imagPCs[:, 2]
@@ -146,10 +146,13 @@ def supernova(
 
 def supernova_pca_model(
-        frequency_array, realPCs, imagPCs, pc_coeff1, pc_coeff2, pc_coeff3,
-        pc_coeff4, pc_coeff5, luminosity_distance, ra, dec, geocent_time, psi):
+        frequency_array, pc_coeff1, pc_coeff2, pc_coeff3, pc_coeff4, pc_coeff5,
+        luminosity_distance, ra, dec, geocent_time, psi, **kwargs):
     """ Supernova signal model """
 
-- 
GitLab